<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN an</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN aus</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Feststelltaste an</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Feststelltaste aus</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Zahlentastenblock an</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Zahlentastenblock aus</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad an</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad aus</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Touchpad umschalten</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn-Umschaltung</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Flugmodus an</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Flugmodus aus</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Ausgewogener Stromverbrauch</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Stromsparen</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>hohe Leistung</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Fenstereffekt angeschaltet</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Fenstereffekt abgeschaltet</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Fenstereffekt anschalten schlug fehl</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>